@@ -364,7 +364,7 @@ sub new {
             $offsets = $self->index_file($path, $opts{-reindex});
             $dirname = dirname($path);
         } else {
-            $self->throw( "$path: Invalid file or dirname");
+            $self->throw( "No file or directory called '$path'");
         }
     }
     @{$self}{qw(dirname offsets)} = ($dirname, $offsets);
@@ -441,7 +441,7 @@ sub glob {
 sub index_dir {
     my ($self, $dir, $force_reindex) = @_;
     my @files = glob( File::Spec->catfile($dir, $self->{glob}) );
-    $self->throw("No suitable files found in $dir") if scalar @files == 0;
+    return if scalar @files == 0;
     $self->{index_name} ||= File::Spec->catfile($dir, 'directory.index');
     my $offsets = $self->_index_files(\@files, $force_reindex);
     return $offsets;
@@ -608,7 +608,13 @@ sub _index_files {
     my $index = $self->index_name;
 
     # If caller has requested reindexing, unlink the index file.
-    unlink $index if $force_reindex;
+    if ($force_reindex) {
+        # Tied-hash in Strawberry Perl creates "$file.index"
+        unlink $index if -e $index;
+        # Tied-hash in ActivePerl creates "$file.index.pag" and "$file.index.dir"
+        unlink "$index.dir" if -e "$index.dir";
+        unlink "$index.pag" if -e "$index.pag";
+    }
 
     # Get the modification time of the index
     my $indextime = (stat $index)[9] || 0;
@@ -747,9 +753,18 @@ sub _calc_termination_length {
     # Account for crlf-terminated Windows and Mac files
     my ($self, $file) = @_;
     my $fh = IO::File->new($file) or $self->throw( "Could not open $file: $!");
-    my $line = <$fh>;
+
+    # In Windows, text files have '\r\n' as line separator, but when reading in
+    # text mode Perl will only show the '\n'. This means that for a line "ABC\r\n",
+    # "length $_" will report 4 although the line is 5 bytes in length.
+    # We assume that all lines have the same line separator and only read current line.
+    my $init_pos   = tell($fh);
+    my $curr_line  = <$fh>;
+    my $pos_diff   = tell($fh) - $init_pos;
+    my $correction = $pos_diff - length $curr_line;
     close $fh;
-    $self->{termination_length} = ($line =~ /\r\n$/) ? 2 : 1;
+
+    $self->{termination_length} = ($curr_line =~ /\r\n$/) ? 2 : 1+$correction;
     return $self->{termination_length};
 }
 
@@ -1056,9 +1071,24 @@ sub NEXTKEY {
 
 sub DESTROY {
     my $self = shift;
+
+    # Close filehandles
+    while (my ($file, $fh) = each %{ $self->{fhcache} }) {
+        if (defined $fh) {
+            $fh->close;
+        }
+    }
+    $self->_close_index($self->{offsets});
+
     if ( $self->{clean} || $self->{indexing} ) {
-      # Indexing aborted or cleaning requested. Delete the index file.
-      unlink $self->{index_name};
+        # Indexing aborted or cleaning requested. Delete the index file.
+        my $index = $self->{index_name};
+
+        # Tied-hash in Strawberry Perl creates "$file.index"
+        unlink $index if -e $index;
+        # Tied-hash in ActivePerl creates "$file.index.pag" and "$file.index.dir"
+        unlink "$index.dir" if -e "$index.dir";
+        unlink "$index.pag" if -e "$index.pag";
     }
     return 1;
 }
@@ -1097,7 +1127,7 @@ sub TIEHANDLE {
 
 sub READLINE {
     my $self = shift;
-    return $self->next_seq;
+    return $self->next_seq || undef;
 }
 
 
