@@ -42,7 +42,7 @@ This implementation handles locations which span more than one
 start/end location, or and/or lie on different sequences, and can
 work with split locations that depend on the specific order of the
 sublocations ('join') or don't have a specific order but represent
-a feature spanning discontiguous sublocations ('order', 'bond').
+a feature spanning noncontiguous sublocations ('order', 'bond').
 
 Note that the order in which sublocations are added may be very important,
 depending on the specific split location type.  For instance, a 'join'
@@ -76,7 +76,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution.  Bug reports can be submitted via the
 web:
 
-  https://redmine.open-bio.org/projects/bioperl/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Jason Stajich
 
@@ -309,9 +309,29 @@ sub is_single_sequence {
 =cut
 
 sub guide_strand {
-	my $self = shift;
-	return $self->{'strand'} = shift if @_;
-	return $self->{'strand'};
+    my $self = shift;
+    return $self->{'strand'} = shift if @_;
+
+    # Sublocations strand values consistency check to set Guide Strand
+    my @subloc_strands;
+    foreach my $loc ($self->sub_Location(0)) {
+        push @subloc_strands, $loc->strand || 1;
+    }
+    if ($self->isa('Bio::Location::SplitLocationI')) {
+        my $identical   = 0;
+        my $first_value = $subloc_strands[0];
+        foreach my $strand (@subloc_strands) {
+            $identical++ if ($strand == $first_value);
+        }
+
+        if ($identical == scalar @subloc_strands) {
+            $self->{'strand'} = $first_value;
+        }
+        else {
+            $self->{'strand'} = undef;
+        }
+    }
+    return $self->{'strand'};
 }
 
 =head1 LocationI methods
@@ -370,8 +390,9 @@ sub strand{
 
   Title   : flip_strand
   Usage   : $location->flip_strand();
-  Function: Flip-flop a strand to the opposite.  Also switch Split strand
-            from undef to -1 or -1 to undef
+  Function: Flip-flop a strand to the opposite.  Also sets Split strand
+            to be consistent with the sublocation strands
+            (1, -1 or undef for mixed strand values)
   Returns : None
   Args    : None
 
@@ -379,12 +400,34 @@ sub strand{
 
 sub flip_strand {
     my $self = shift;
+    my @sublocs;
+    my @subloc_strands;
+
     for my $loc ( $self->sub_Location(0) ) {
-		$loc->flip_strand;
-		if ($loc->isa('Bio::Location::SplitLocationI')) {
-			my $gs = ($self->guide_strand == -1) ? undef : -1;
-			$loc->guide_strand($gs);
-		}
+        # Atomic "flip_strand" now initialize strand if necessary
+        my $new_strand = $loc->flip_strand;
+
+        # Store strand values for later consistency check
+        push @sublocs, $loc;
+        push @subloc_strands, $new_strand;
+    }
+
+    # Sublocations strand values consistency check to set Guide Strand
+    if ($self->isa('Bio::Location::SplitLocationI')) {
+        my $identical   = 0;
+        my $first_value = $subloc_strands[0];
+        foreach my $strand (@subloc_strands) {
+            $identical++ if ($strand == $first_value);
+        }
+
+        if ($identical == scalar @subloc_strands) {
+            $self->guide_strand($first_value);
+        }
+        else {
+            # Mixed strand values, must reverse the sublocations order
+            $self->guide_strand(undef);
+            @{ $self->{_sublocations} } = reverse @sublocs;
+        }
     }
 }
 
@@ -560,6 +603,80 @@ sub end_pos_type {
     return ( @locs ) ? $locs[0]->end_pos_type() : undef;    
 }
 
+=head2 length
+
+ Title   : length
+ Usage   : $len = $loc->length();
+ Function: get the length in the coordinate space this location spans
+ Example :
+ Returns : an integer
+ Args    : none
+
+=cut
+
+sub length {
+    my ($self) = @_;
+    my $length = 0;
+    # Mixed strand values means transplicing (where exons can even
+    # be in different chromosomes), so in that case only give the sum
+    # of the lengths of the individual segments
+    if (! defined $self->guide_strand) {
+        for my $loc ( $self->sub_Location(0) ) {
+            $length += abs($loc->end - $loc->start) + 1
+        }
+    }
+    else {
+        my @sublocs = $self->sub_Location(0);
+        my $start   = $sublocs[0]->start;
+        my $end     = $sublocs[-1]->end;
+
+        # If Start > End, its a possible case of cut by origin
+        # location in circular sequences (e.g "join(16..20,1..2)")
+        if ($start > $end) {
+            # Figure out which segments are located before
+            # and which are located after coordinate 1
+            # (END_SEQ - 1 - START_SEQ)
+            my @end_seq_segments;
+            my @start_seq_segments;
+            my $switch = 0;
+            foreach my $subloc (@sublocs) {
+                if ($switch == 0) {
+                    if ($subloc->start == 1) {
+                        $switch = 1;
+                        push @start_seq_segments, $subloc;
+                    }
+                    else {
+                        push @end_seq_segments, $subloc;
+                    }
+                }
+                else {
+                    push @start_seq_segments, $subloc;
+                }
+            }
+
+            # If its a cut by origin location, sum the whole length of each group
+            if (scalar @end_seq_segments > 0 and @start_seq_segments > 0) {
+                my $end_segments_length   = abs(  $end_seq_segments[0]->start
+                                                - $end_seq_segments[-1]->end)
+                                                + 1;
+                my $start_segments_length = abs(  $start_seq_segments[0]->start
+                                                - $start_seq_segments[-1]->end)
+                                                + 1;
+                $length = $end_segments_length + $start_segments_length;
+            }
+        }
+        else {
+            $length = $end - $start + 1;
+        }
+    }
+
+    # If for some reason nothing worked, fall back to previous behaviour
+    if ($length == 0) {
+        $length = abs($self->end - $self->start) + 1
+    }
+
+    return $length;
+}
 
 =head2 seq_id
 
@@ -626,19 +743,13 @@ sub to_FTstring {
     my @strs;
 	my $strand = $self->strand() || 0;
 	my $stype = lc($self->splittype());
-	my $guide = $self->guide_strand();
 
     if( $strand < 0 ) {
 		$self->flip_strand; # this will recursively set the strand
 							# to +1 for all the sub locations
     }
-	# If the split type is join, the order is important;
-	# otherwise must be 5'->3' regardless
-	
-	my @locs = ($stype eq 'join' && (!$guide && $strand == -1)) ?
-	           reverse $self->sub_Location() : $self->sub_Location() ;
-	
-    foreach my $loc ( @locs ) {
+    
+    foreach my $loc ( $self->sub_Location(0) ) {
 		$loc->verbose($self->verbose);
 		my $str = $loc->to_FTstring();
 		# we only append the remote seq_id if it hasn't been done already
