@@ -11,6 +11,7 @@
 
 # POD documentation - main docs before the code
 
+
 =head1 NAME
 
 Bio::PrimarySeqI - Interface definition for a Bio::PrimarySeq
@@ -36,11 +37,11 @@ Bio::PrimarySeqI - Interface definition for a Bio::PrimarySeq
 
     # Object manipulation
     eval {
-	   $rev = $obj->revcom();
+       $rev = $obj->revcom();
     };
     if( $@ ) {
-	   $obj->throw("Could not reverse complement. ".
-		    "Probably not DNA. Actual exception\n$@\n");
+       $obj->throw( "Could not reverse complement. ".
+                    "Probably not DNA. Actual exception\n$@\n" );
     }
 
     $trunc = $obj->trunc(12,50);
@@ -104,7 +105,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution.  Bug reports can be submitted via the
 web:
 
-  https://redmine.open-bio.org/projects/bioperl/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Ewan Birney
 
@@ -118,16 +119,14 @@ methods. Internal methods are usually preceded with a _
 =cut
 
 
-# Let the code begin...
-
-
 package Bio::PrimarySeqI;
 use strict;
 use Bio::Tools::CodonTable;
 
 use base qw(Bio::Root::RootI);
 
-=head1 Implementation Specific Functions
+
+=head1 Implementation-specific Functions
 
 These functions are the ones that a specific implementation must
 define.
@@ -147,10 +146,11 @@ define.
 =cut
 
 sub seq {
-   my ($self) = @_;
-   $self->throw_not_implemented();
+    my ($self) = @_;
+    $self->throw_not_implemented();
 }
 
+
 =head2 subseq
 
  Title   : subseq
@@ -167,11 +167,12 @@ sub seq {
 
 =cut
 
-sub subseq{
-   my ($self) = @_;
-   $self->throw_not_implemented();
+sub subseq {
+    my ($self) = @_;
+    $self->throw_not_implemented();
 }
 
+
 =head2 display_id
 
  Title   : display_id
@@ -196,12 +197,11 @@ sub subseq{
  Args    : None
  Status  : Virtual
 
-
 =cut
 
 sub display_id {
-   my ($self) = @_;
-   $self->throw_not_implemented();
+    my ($self) = @_;
+    $self->throw_not_implemented();
 }
 
 
@@ -222,16 +222,14 @@ sub display_id {
  Args    : None
  Status  : Virtual
 
-
 =cut
 
 sub accession_number {
-   my ($self,@args) = @_;
-   $self->throw_not_implemented();
+    my ($self,@args) = @_;
+    $self->throw_not_implemented();
 }
 
 
-
 =head2 primary_id
 
  Title   : primary_id
@@ -248,12 +246,11 @@ sub accession_number {
  Args    : None
  Status  : Virtual
 
-
 =cut
 
 sub primary_id {
-   my ($self,@args) = @_;
-   $self->throw_not_implemented();
+    my ($self,@args) = @_;
+    $self->throw_not_implemented();
 }
 
 
@@ -262,7 +259,7 @@ sub primary_id {
  Title   : can_call_new
  Usage   : if( $obj->can_call_new ) {
              $newobj = $obj->new( %param );
-	 }
+         }
  Function: Can_call_new returns 1 or 0 depending
            on whether an implementation allows new
            constructor to be called. If a new constructor
@@ -270,24 +267,23 @@ sub primary_id {
            constructor list.
 
            $myobject->new( -seq => $sequence_as_string,
-			   -display_id  => $id
-			   -accession_number => $accession
-			   -alphabet => 'dna',
-			   );
+                           -display_id  => $id
+                           -accession_number => $accession
+                           -alphabet => 'dna',
+                           );
  Returns : 1 or 0
  Args    :
 
 
 =cut
 
-sub can_call_new{
-   my ($self,@args) = @_;
-
-   # we default to 0 here
-
-   return 0;
+sub can_call_new {
+    my ($self,@args) = @_;
+    # we default to 0 here
+    return 0;
 }
 
+
 =head2 alphabet
 
  Title   : alphabet
@@ -304,14 +300,14 @@ sub can_call_new{
  Args    : None
  Status  : Virtual
 
-
 =cut
 
-sub alphabet{
+sub alphabet {
     my ( $self ) = @_;
     $self->throw_not_implemented();
 }
 
+
 =head2 moltype
 
  Title   : moltype
@@ -319,15 +315,14 @@ sub alphabet{
 
 =cut
 
-sub moltype{
-   my ($self,@args) = @_;
-
-   $self->warn("moltype: pre v1.0 method. Calling alphabet() instead...");
-   $self->alphabet(@args);
+sub moltype {
+    my ($self,@args) = @_;
+    $self->warn("moltype: pre v1.0 method. Calling alphabet() instead...");
+    return $self->alphabet(@args);
 }
 
 
-=head1 Optional Implementation Functions
+=head1 Implementation-optional Functions
 
 The following functions rely on the above functions. An
 implementing class does not need to provide these functions, as they
@@ -354,7 +349,7 @@ are encouraged to override these methods
            The id is the same id as the original sequence, and the
            accession number is also indentical. If someone wants to
            track that this sequence has be reversed, it needs to
-           define its own extensionsj.
+           define its own extensions.
 
            To do an inplace edit of an object you can go:
 
@@ -370,65 +365,70 @@ are encouraged to override these methods
 
 =cut
 
-sub revcom{
-   my ($self) = @_;
-
-
-   # check the type is good first.
-   my $t = $self->alphabet;
-
-   if( $t eq 'protein' ) {
-       $self->throw("Sequence is a protein. Cannot revcom");
-   }
-
-   if( $t ne 'dna' && $t ne 'rna' ) {
-       if( $self->can('warn') ) {
-	   $self->warn("Sequence is not dna or rna, but [$t]. ".
-		       "Attempting to revcom, but unsure if this is right");
-       } else {
-	   warn("[$self] Sequence is not dna or rna, but [$t]. ".
-		"Attempting to revcom, but unsure if this is right");
-       }
-   }
-
-   # yank out the sequence string
-
-   my $str = $self->seq();
-
-   # if is RNA - map to DNA then map back
-
-   if( $t eq 'rna' ) {
-       $str =~ tr/uU/tT/;
-   }
-
-   # revcom etc...
-
-   $str =~ tr/acgtrymkswhbvdnxACGTRYMKSWHBVDNX/tgcayrkmswdvbhnxTGCAYRKMSWDVBHNX/;
-   my $revseq = CORE::reverse $str;
-
-   if( $t eq 'rna' ) {
-       $revseq =~ tr/tT/uU/;
-   }
-
-   my $seqclass;
-   if($self->can_call_new()) {
-       $seqclass = ref($self);
-   } else {
-       $seqclass = 'Bio::PrimarySeq';
-       $self->_attempt_to_load_Seq();
-   }
-   my $out = $seqclass->new( '-seq' => $revseq,
-			     '-is_circular'  => $self->is_circular,
-			     '-display_id'  => $self->display_id,
-			     '-accession_number' => $self->accession_number,
-			     '-alphabet' => $self->alphabet,
-			     '-desc' => $self->desc(),
-                             '-verbose' => $self->verbose
-			     );
-   return $out;
+sub revcom {
+    my ($self) = @_;
 
+    # Create a new fresh object if $self is 'Bio::Seq::LargePrimarySeq'
+    # or 'Bio::Seq::LargeSeq', if not take advantage of
+    # Bio::Root::clone to get an object copy
+    my $out;
+    if (   $self->isa('Bio::Seq::LargePrimarySeq')
+        or $self->isa('Bio::Seq::LargeSeq')
+        ) {
+        my ($seqclass, $opts) = $self->_setup_class;
+        $out = $seqclass->new(
+            -seq              => $self->_revcom_from_string($self->seq, $self->alphabet),
+            -is_circular      => $self->is_circular,
+            -display_id       => $self->display_id,
+            -accession_number => $self->accession_number,
+            -alphabet         => $self->alphabet,
+            -desc             => $self->desc,
+            -verbose          => $self->verbose,
+            %$opts,
+        );
+    } else {
+        $out = $self->clone;
+        $out->seq( $out->_revcom_from_string($out->seq, $out->alphabet) );
+    }
+    return $out;
 }
 
+
+sub _revcom_from_string {
+    my ($self, $string, $alphabet) = @_;
+
+    # Check that reverse-complementing makes sense
+    if( $alphabet eq 'protein' ) {
+        $self->throw("Sequence is a protein. Cannot revcom.");
+    }
+    if( $alphabet ne 'dna' && $alphabet ne 'rna' ) {
+        my $msg = "Sequence is not dna or rna, but [$alphabet]. Attempting to revcom, ".
+                  "but unsure if this is right.";
+        if( $self->can('warn') ) {
+            $self->warn($msg);
+        } else {
+            warn("[$self] $msg");
+        }
+    }
+
+    # If sequence is RNA, map to DNA (then map back later)
+    if( $alphabet eq 'rna' ) {
+        $string =~ tr/uU/tT/;
+    }
+
+    # Reverse-complement now
+    $string =~ tr/acgtrymkswhbvdnxACGTRYMKSWHBVDNX/tgcayrkmswdvbhnxTGCAYRKMSWDVBHNX/;
+    $string = CORE::reverse $string;
+
+    # Map back RNA to DNA
+    if( $alphabet eq 'rna' ) {
+        $string =~ tr/tT/uU/;
+    }
+
+    return $string;
+}
+
+
 =head2 trunc
 
  Title   : trunc
@@ -440,40 +440,47 @@ sub revcom{
 
 =cut
 
-sub trunc{
-   my ($self,$start,$end) = @_;
+sub trunc {
+    my ($self,$start,$end) = @_;
 
-   my $str;
-   if( defined $start && ref($start) &&
-       $start->isa('Bio::LocationI') ) {
-       $str = $self->subseq($start); # start is a location actually
-   } elsif( !$end ) {
-       $self->throw("trunc start,end -- there was no end for $start");
-   } elsif( $end < $start ) {
-       my $msg = "start [$start] is greater than end [$end]. \n".
-	   "If you want to truncated and reverse complement, \n".
-	       "you must call trunc followed by revcom. Sorry.";
-       $self->throw($msg);
-   } else {
-       $str = $self->subseq($start,$end);
-   }
+    my $str;
+    if( defined $start && ref($start) &&
+        $start->isa('Bio::LocationI') ) {
+        $str = $self->subseq($start); # start is a location actually
+    } elsif( !$end ) {
+        $self->throw("trunc start,end -- there was no end for $start");
+    } elsif( $end < $start ) {
+        my $msg = "start [$start] is greater than end [$end]. \n".
+                  "If you want to truncated and reverse complement, \n".
+                  "you must call trunc followed by revcom. Sorry.";
+        $self->throw($msg);
+    } else {
+        $str = $self->subseq($start,$end);
+    }
 
-   my $seqclass;
-   if($self->can_call_new()) {
-       $seqclass = ref($self);
-   } else {
-       $seqclass = 'Bio::PrimarySeq';
-       $self->_attempt_to_load_Seq();
-   }
-
-   my $out = $seqclass->new( '-seq' => $str,
-			     '-display_id'  => $self->display_id,
-			     '-accession_number' => $self->accession_number,
-			     '-alphabet' => $self->alphabet,
-			     '-desc' => $self->desc(),
-                             '-verbose' => $self->verbose
-			     );
-   return $out;
+    # Create a new fresh object if $self is 'Bio::Seq::LargePrimarySeq'
+    # or 'Bio::Seq::LargeSeq', if not take advantage of
+    # Bio::Root::clone to get an object copy
+    my $out;
+    if (   $self->isa('Bio::Seq::LargePrimarySeq')
+        or $self->isa('Bio::Seq::LargeSeq')
+        ) {
+        my ($seqclass, $opts) = $self->_setup_class;
+        $out = $seqclass->new(
+            -seq              => $str,
+            -is_circular      => $self->is_circular,
+            -display_id       => $self->display_id,
+            -accession_number => $self->accession_number,
+            -alphabet         => $self->alphabet,
+            -desc             => $self->desc,
+            -verbose          => $self->verbose,
+            %$opts,
+        );
+    } else {
+        $out = $self->clone;
+        $out->seq($str);
+    }
+    return $out;
 }
 
 
@@ -569,15 +576,15 @@ element in an array:
 =cut
 
 sub translate {
-	 my ($self,@args) = @_;
-     my ($terminator, $unknown, $frame, $codonTableId, $complete,
-     $complete_codons, $throw, $codonTable, $orf, $start_codon, $offset);
+    my ($self,@args) = @_;
+    my ($terminator, $unknown, $frame, $codonTableId, $complete,
+        $complete_codons, $throw, $codonTable, $orf, $start_codon, $offset);
 
-	 ## new API with named parameters, post 1.5.1
-	 if ($args[0] && $args[0] =~ /^-[A-Z]+/i) {
-         ($terminator, $unknown, $frame, $codonTableId, $complete,
-         $complete_codons, $throw,$codonTable, $orf, $start_codon, $offset) =
-			 $self->_rearrange([qw(TERMINATOR
+    ## new API with named parameters, post 1.5.1
+    if ($args[0] && $args[0] =~ /^-[A-Z]+/i) {
+        ($terminator, $unknown, $frame, $codonTableId, $complete,
+        $complete_codons, $throw,$codonTable, $orf, $start_codon, $offset) =
+            $self->_rearrange([qw(TERMINATOR
                                                UNKNOWN
                                                FRAME
                                                CODONTABLE_ID
@@ -588,11 +595,11 @@ sub translate {
                                                ORF
                                                START
                                                OFFSET)], @args);
-	 ## old API, 1.5.1 and preceding versions
-	 } else {
-		 ($terminator, $unknown, $frame, $codonTableId,
-		  $complete, $throw, $codonTable, $offset) = @args;
-	 }
+    ## old API, 1.5.1 and preceding versions
+    } else {
+        ($terminator, $unknown, $frame, $codonTableId,
+         $complete, $throw, $codonTable, $offset) = @args;
+    }
     
     ## Initialize termination codon, unknown codon, codon table id, frame
     $terminator = '*'    unless (defined($terminator) and $terminator ne '');
@@ -603,46 +610,45 @@ sub translate {
     
     ## Get a CodonTable, error if custom CodonTable is invalid
     if ($codonTable) {
-		 $self->throw("Need a Bio::Tools::CodonTable object, not ". $codonTable)
-			unless $codonTable->isa('Bio::Tools::CodonTable');
+        $self->throw("Need a Bio::Tools::CodonTable object, not ". $codonTable)
+            unless $codonTable->isa('Bio::Tools::CodonTable');
     } else {
         
         # shouldn't this be cached?  Seems wasteful to have a new instance
         # every time...
-		$codonTable = Bio::Tools::CodonTable->new( -id => $codonTableId);
-	 }
+        $codonTable = Bio::Tools::CodonTable->new( -id => $codonTableId);
+    }
 
     ## Error if alphabet is "protein"
     $self->throw("Can't translate an amino acid sequence.") if
-		($self->alphabet =~ /protein/i);
+        ($self->alphabet =~ /protein/i);
 
     ## Error if -start parameter isn't a valid codon
-	 if ($start_codon) {
-		 $self->throw("Invalid start codon: $start_codon.") if
-			( $start_codon !~ /^[A-Z]{3}$/i );
-	 }
+    if ($start_codon) {
+        $self->throw("Invalid start codon: $start_codon.") if
+            ( $start_codon !~ /^[A-Z]{3}$/i );
+    }
 
-	 my $seq;
-
-	 if ($offset) {
-		$self->throw("Offset must be 1, 2, or 3.") if
-		    ( $offset !~ /^[123]$/ );
-		my ($start, $end) = ($offset, $self->length);
-		($seq) = $self->subseq($start, $end);
-	 } else {
-		($seq) = $self->seq();
-	 }
+    my $seq;
+    if ($offset) {
+        $self->throw("Offset must be 1, 2, or 3.") if
+            ( $offset !~ /^[123]$/ );
+        my ($start, $end) = ($offset, $self->length);
+        ($seq) = $self->subseq($start, $end);
+    } else {
+        ($seq) = $self->seq();
+    }
 
          ## ignore frame if an ORF is supposed to be found
-	 if ( $orf ) {
-            my ($orf_region) = $self->_find_orfs_nucleotide( $seq, $codonTable, $start_codon, $orf eq 'longest' ? 0 : 'first_only' );
-            $seq = $self->_orf_sequence( $seq, $orf_region );
-	 } else {
-	 ## use frame, error if frame is not 0, 1 or 2
-		 $self->throw("Valid values for frame are 0, 1, or 2, not $frame.")
-			unless ($frame == 0 or $frame == 1 or $frame == 2);
-		 $seq = substr($seq,$frame);
-         }
+    if ( $orf ) {
+        my ($orf_region) = $self->_find_orfs_nucleotide( $seq, $codonTable, $start_codon, $orf eq 'longest' ? 0 : 'first_only' );
+        $seq = $self->_orf_sequence( $seq, $orf_region );
+    } else {
+        ## use frame, error if frame is not 0, 1 or 2
+        $self->throw("Valid values for frame are 0, 1, or 2, not $frame.")
+            unless ($frame == 0 or $frame == 1 or $frame == 2);
+        $seq = substr($seq,$frame);
+    }
 
     ## Translate it
     my $output = $codonTable->translate($seq, $complete_codons);
@@ -652,51 +658,59 @@ sub translate {
 
     ## Only if we are expecting to translate a complete coding region
     if ($complete) {
-		 my $id = $self->display_id;
-		 # remove the terminator character
-		 if( substr($output,-1,1) eq $terminator ) {
-			 chop $output;
-		 } else {
-			 $throw && $self->throw("Seq [$id]: Not using a valid terminator codon!");
-			 $self->warn("Seq [$id]: Not using a valid terminator codon!");
-		 }
-		 # test if there are terminator characters inside the protein sequence!
-		 if ($output =~ /\Q$terminator\E/) {
-             $id ||= '';
-			 $throw && $self->throw("Seq [$id]: Terminator codon inside CDS!");
-			 $self->warn("Seq [$id]: Terminator codon inside CDS!");
-		 }
-		 # if the initiator codon is not ATG, the amino acid needs to be changed to M
-		 if ( substr($output,0,1) ne 'M' ) {
-			 if ($codonTable->is_start_codon(substr($seq, 0, 3)) ) {
-				 $output = 'M'. substr($output,1);
-			 }	elsif ($throw) {
-				 $self->throw("Seq [$id]: Not using a valid initiator codon!");
-			 } else {
-				 $self->warn("Seq [$id]: Not using a valid initiator codon!");
-			 }
-		 }
+        my $id = $self->display_id;
+        # remove the terminator character
+        if( substr($output,-1,1) eq $terminator ) {
+            chop $output;
+        } else {
+            $throw && $self->throw("Seq [$id]: Not using a valid terminator codon!");
+            $self->warn("Seq [$id]: Not using a valid terminator codon!");
+        }
+        # test if there are terminator characters inside the protein sequence!
+        if ($output =~ /\Q$terminator\E/) {
+            $id ||= '';
+            $throw && $self->throw("Seq [$id]: Terminator codon inside CDS!");
+            $self->warn("Seq [$id]: Terminator codon inside CDS!");
+        }
+        # if the initiator codon is not ATG, the amino acid needs to be changed to M
+        if ( substr($output,0,1) ne 'M' ) {
+            if ($codonTable->is_start_codon(substr($seq, 0, 3)) ) {
+                $output = 'M'. substr($output,1);
+            } elsif ($throw) {
+                $self->throw("Seq [$id]: Not using a valid initiator codon!");
+            } else {
+                $self->warn("Seq [$id]: Not using a valid initiator codon!");
+            }
+        }
     }
 
-    my $seqclass;
-    if ($self->can_call_new()) {
-		 $seqclass = ref($self);
+    # Create a new fresh object if $self is 'Bio::Seq::LargePrimarySeq'
+    # or 'Bio::Seq::LargeSeq', if not take advantage of
+    # Bio::Root::clone to get an object copy
+    my $out;
+    if (   $self->isa('Bio::Seq::LargePrimarySeq')
+        or $self->isa('Bio::Seq::LargeSeq')
+        ) {
+        my ($seqclass, $opts) = $self->_setup_class;
+        $out = $seqclass->new(
+            -seq              => $output,
+            -is_circular      => $self->is_circular,
+            -display_id       => $self->display_id,
+            -accession_number => $self->accession_number,
+            -alphabet         => 'protein',
+            -desc             => $self->desc,
+            -verbose          => $self->verbose,
+            %$opts,
+        );
     } else {
-		 $seqclass = 'Bio::PrimarySeq';
-		 $self->_attempt_to_load_Seq();
+        $out = $self->clone;
+        $out->seq($output);
+        $out->alphabet('protein');
     }
-    my $out = $seqclass->new( '-seq' => $output,
-										'-display_id'  => $self->display_id,
-										'-accession_number' => $self->accession_number,
-										# is there anything wrong with retaining the
-										# description?
-										'-desc' => $self->desc(),
-										'-alphabet' => 'protein',
-                              '-verbose' => $self->verbose
-			      );
     return $out;
 }
 
+
 =head2 transcribe()
 
  Title   : transcribe
@@ -713,24 +727,36 @@ sub transcribe {
     return unless $self->alphabet eq 'dna';
     my $s = $self->seq;
     $s =~ tr/tT/uU/;
-    my $class;
-    if ($self->can_call_new) {
-	$class = ref($self);
-    } else {
-	$class = 'Bio::PrimarySeq';
-	$self->_attempt_to_load_Seq;
-    }
     my $desc = $self->desc || '';
-    return $class->new(
-	'-seq' => $s,
-	'-alphabet' => 'rna',
-	'-display_id'  => $self->display_id,
-	'-accession_number' => $self->accession_number,
-	'-desc' => "${desc}[TRANSCRIBED]",
-	'-verbose' => $self->verbose
-	);
+
+    # Create a new fresh object if $self is 'Bio::Seq::LargePrimarySeq'
+    # or 'Bio::Seq::LargeSeq', if not take advantage of
+    # Bio::Root::clone to get an object copy
+    my $out;
+    if (   $self->isa('Bio::Seq::LargePrimarySeq')
+        or $self->isa('Bio::Seq::LargeSeq')
+        ) {
+        my ($seqclass, $opts) = $self->_setup_class;
+        $out = $seqclass->new(
+            -seq              => $s,
+            -is_circular      => $self->is_circular,
+            -display_id       => $self->display_id,
+            -accession_number => $self->accession_number,
+            -alphabet         => 'rna',
+            -desc             => "${desc}[TRANSCRIBED]",
+            -verbose          => $self->verbose,
+            %$opts,
+        );
+    } else {
+        $out = $self->clone;
+        $out->seq($s);
+        $out->alphabet('rna');
+        $out->desc($desc . "[TRANSCRIBED]");
+    }
+    return $out;
 }
 
+
 =head2 rev_transcribe()
 
  Title   : rev_transcribe
@@ -747,23 +773,36 @@ sub rev_transcribe {
     return unless $self->alphabet eq 'rna';
     my $s = $self->seq;
     $s =~ tr/uU/tT/;
-    my $class;
-    if ($self->can_call_new) {
-	$class = ref($self);
+    my $desc = $self->desc || '';
+
+    # Create a new fresh object if $self is 'Bio::Seq::LargePrimarySeq'
+    # or 'Bio::Seq::LargeSeq', if not take advantage of
+    # Bio::Root::clone to get an object copy
+    my $out;
+    if (   $self->isa('Bio::Seq::LargePrimarySeq')
+        or $self->isa('Bio::Seq::LargeSeq')
+        ) {
+        my ($seqclass, $opts) = $self->_setup_class;
+        $out = $seqclass->new(
+            -seq              => $s,
+            -is_circular      => $self->is_circular,
+            -display_id       => $self->display_id,
+            -accession_number => $self->accession_number,
+            -alphabet         => 'dna',
+            -desc             => $self->desc . "[REVERSE TRANSCRIBED]",
+            -verbose          => $self->verbose,
+            %$opts,
+        );
     } else {
-	$class = 'Bio::PrimarySeq';
-	$self->_attempt_to_load_Seq;
+        $out = $self->clone;
+        $out->seq($s);
+        $out->alphabet('dna');
+        $out->desc($desc . "[REVERSE TRANSCRIBED]");
     }
-    return $class->new(
-	'-seq' => $s,
-	'-alphabet' => 'dna',
-	'-display_id'  => $self->display_id,
-	'-accession_number' => $self->accession_number,
-	'-desc' => $self->desc . "[REVERSE TRANSCRIBED]",
-	'-verbose' => $self->verbose
-	);
+    return $out;
 }
 
+
 =head2 id
 
  Title   : id
@@ -775,9 +814,8 @@ sub rev_transcribe {
 
 =cut
 
-sub  id {
+sub id {
    my ($self)= @_;
-
    return $self->display_id();
 }
 
@@ -792,11 +830,12 @@ sub  id {
 
 =cut
 
-sub  length {
-   my ($self)= @_;
-   $self->throw_not_implemented();
+sub length {
+    my ($self)= @_;
+    $self->throw_not_implemented();
 }
 
+
 =head2 desc
 
  Title   : desc
@@ -816,17 +855,18 @@ sub desc {
 =head2 is_circular
 
  Title   : is_circular
- Usage   : if( $obj->is_circular) { /Do Something/ }
+ Usage   : if( $obj->is_circular) { # Do something }
  Function: Returns true if the molecule is circular
  Returns : Boolean value
  Args    : none
 
 =cut
 
-sub is_circular{
+sub is_circular {
     shift->throw_not_implemented;
 }
 
+
 =head1 Private functions
 
 These are some private functions for the PrimarySeqI interface. You do not
@@ -901,16 +941,20 @@ sub _find_orfs_nucleotide {
     return sort { $b->[2] <=> $a->[2] } @orfs;
 }
 
+
 sub _truncate_seq {
-    my ($self,$seq) = @_;
+    my ($self, $seq) = @_;
     return CORE::length($seq) > 200 ? substr($seq,0,50).'...'.substr($seq,-50) : $seq;
 }
+
+
 sub _orf_sequence {
     my ($self, $seq, $orf ) = @_;
     return '' unless $orf;
     return substr( $seq, $orf->[0], $orf->[2] )
 }
 
+
 =head2 _attempt_to_load_Seq
 
  Title   : _attempt_to_load_Seq
@@ -920,31 +964,50 @@ sub _orf_sequence {
  Returns :
  Args    :
 
-
 =cut
 
-sub _attempt_to_load_Seq{
-   my ($self) = @_;
-
-   if( $main::{'Bio::PrimarySeq'} ) {
-       return 1;
-   } else {
-       eval {
-	   require Bio::PrimarySeq;
-       };
-       if( $@ ) {
-	   my $text = "Bio::PrimarySeq could not be loaded for [$self]\n".
-	       "This indicates that you are using Bio::PrimarySeqI ".
-	       "without Bio::PrimarySeq loaded or without providing a ".
-	       "complete implementation.\nThe most likely problem is that there ".
-	       "has been a misconfiguration of the bioperl environment\n".
-	       "Actual exception:\n\n";
-	   $self->throw("$text$@\n");
-	   return 0;
-       }
-       return 1;
-   }
+sub _attempt_to_load_Seq {
+    my ($self) = @_;
 
+    if( $main::{'Bio::PrimarySeq'} ) {
+        return 1;
+    } else {
+        eval {
+            require Bio::PrimarySeq;
+        };
+        if( $@ ) {
+            my $text = "Bio::PrimarySeq could not be loaded for [$self]\n".
+                "This indicates that you are using Bio::PrimarySeqI ".
+                "without Bio::PrimarySeq loaded or without providing a ".
+                "complete implementation.\nThe most likely problem is that there ".
+                "has been a misconfiguration of the bioperl environment\n".
+                "Actual exception:\n\n";
+            $self->throw("$text$@\n");
+            return 0;
+        }
+        return 1;
+    }
 }
 
+
+sub _setup_class {
+    # Return name of class and setup some default parameters
+    my ($self) = @_;
+    my $seqclass;
+    if ($self->can_call_new()) {
+        $seqclass = ref($self);
+    } else {
+        $seqclass = 'Bio::PrimarySeq';
+        $self->_attempt_to_load_Seq();
+    }
+    my %opts;
+    if ($seqclass eq 'Bio::PrimarySeq') {
+        # Since sequence is in a Seq object, it has already been validated.
+        # We do not need to validate its trunc(), revcom(), etc
+        $opts{ -direct } = 1;
+    }
+    return $seqclass, \%opts;
+}
+
+
 1;
