@@ -1,10 +1,13 @@
-package	Bio::Root::Utilities;
+package Bio::Root::Utilities;
 use strict;
+use Bio::Root::IO;
+use Bio::Root::Exception;
+use base qw(Bio::Root::Root Exporter);
 
-
-=head1 NAME
-
-Bio::Root::Utilities - General-purpose utility module
+# ABSTRACT: general-purpose utility module
+# AUTHOR:   Steve Chervitz <sac@bioperl.org>
+# OWNER:    1996-2007 Steve Chervitz
+# LICENSE:  Perl_5
 
 =head1 SYNOPSIS
 
@@ -56,88 +59,30 @@ Follow the installation instructions included in the README file.
 
 =head1 DEPENDENCIES
 
-Inherits from L<Bio::Root::Root>, and uses L<Bio::Root::IO> 
+Inherits from L<Bio::Root::Root>, and uses L<Bio::Root::IO>
 and L<Bio::Root::Exception>.
 
-Relies on external executables for file compression/uncompression 
-and sending mail. No paths to these are hard coded but are located 
+Relies on external executables for file compression/uncompression
+and sending mail. No paths to these are hard coded but are located
 as needed.
 
 =head1 SEE ALSO
 
   http://bioperl.org  - Bioperl Project Homepage
 
-=head1 FEEDBACK
-
-=head2 Mailing Lists
-
-User feedback is an integral part of the evolution of this and other Bioperl modules.
-Send your comments and suggestions preferably to one of the Bioperl mailing lists.
-Your participation is much appreciated.
-
-  bioperl-l@bioperl.org                  - General discussion
-  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
-
-=head2 Support 
-
-Please direct usage questions or support issues to the mailing list:
-
-I<bioperl-l@bioperl.org>
-
-rather than to the module maintainer directly. Many experienced and 
-reponsive experts will be able look at the problem and quickly 
-address it. Please include a thorough description of the problem 
-with code and data examples if at all possible.
-
-=head2 Reporting Bugs
-
-Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution. Bug reports can be submitted via the
-web:
-
-  https://redmine.open-bio.org/projects/bioperl/
-
-=head1 AUTHOR
-
-Steve Chervitz E<lt>sac@bioperl.orgE<gt>
-
-See L<the FEEDBACK section | FEEDBACK> for where to send bug reports and comments.
-
-
 =head1 ACKNOWLEDGEMENTS
 
 This module was originally developed under the auspices of the
 Saccharomyces Genome Database: http://www.yeastgenome.org/
 
-=head1 COPYRIGHT
-
-Copyright (c) 1996-2007 Steve Chervitz. All Rights Reserved.
-This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself.
-
 =cut
 
-=head1 APPENDIX
-
-Methods beginning with a leading underscore are considered private
-and are intended for internal use by this module. They are
-B<not> considered part of the public interface and are described here
-for documentation purposes only.
-
-=cut
-
-# Let the code begin...
-
-use Bio::Root::IO;
-use Bio::Root::Exception;
-
 use vars qw(@EXPORT_OK %EXPORT_TAGS);
-use base qw(Bio::Root::Root Exporter);
 @EXPORT_OK   = qw($Util);
 %EXPORT_TAGS = ( obj => [qw($Util)],
-		   std => [qw($Util)],);
+                 std => [qw($Util)],);
 
-use vars qw($ID $Util $GNU_PATH $TIMEOUT_SECS 
+use vars qw($ID $Util $GNU_PATH $TIMEOUT_SECS
             @COMPRESSION_UTILS @UNCOMPRESSION_UTILS
             $DEFAULT_NEWLINE $NEWLINE $AUTHORITY
             @MONTHS @DAYS $BASE_YEAR $DEFAULT_CENTURY
@@ -156,7 +101,7 @@ $DEFAULT_CENTURY = $BASE_YEAR + 100;
 # The first executable in this list to be found in the current PATH will be used,
 # unless overridden in the call to that function. See docs for details.
 @COMPRESSION_UTILS = qw(gzip bzip2 zip compress);
-@UNCOMPRESSION_UTILS = qw(gunzip bunzip2 unzip uncompress);
+@UNCOMPRESSION_UTILS = qw(gunzip gzip bunzip2 unzip uncompress);
 
 # Default person to receive feedback from users and possibly automatic error messages.
 $AUTHORITY = '';
@@ -186,7 +131,7 @@ $Util = Bio::Root::Root->new();
  Purpose   : -- Get a string containing the formated date or time
            :    taken when this routine is invoked.
            : -- Provides a way to avoid using `date`.
-	   : -- Provides an interface to localtime().
+           : -- Provides an interface to localtime().
            : -- Interconverts some date formats.
            :
            : (For additional functionality, use Date::Manip or
@@ -205,7 +150,7 @@ $Util = Bio::Root::Root->new();
            :   'ymd'         = 96may3
            :   'md'          = may3
            :   'year'        = 1996
-           :   'hms'         = 23:01:59  # when not converting a format, 'hms' can be 
+           :   'hms'         = 23:01:59  # when not converting a format, 'hms' can be
            :                             # tacked on to any of the above options
            :                             # to add the time stamp: eg 'dmyhms'
            :   'full' | 'unix' = UNIX-style date: Tue May  5 22:00:00 1998
@@ -214,7 +159,7 @@ $Util = Bio::Root::Root->new();
            : FMT  = yyyy-mm-dd | yyyy-dd-mm | yyyy-mmm-dd |
            :        mdy | ymd | md | d-m-y | hms | hm
            :        ('hms' may be appended to any of these to
-	   :        add a time stamp)
+           :        add a time stamp)
            :
            : DATE = String containing date to be converted.
            :        Acceptable input formats:
@@ -249,19 +194,19 @@ sub date_format {
     # Load a supplied date for conversion:
     if(defined($date) && ($date =~ /[\D-]+/)) {
         $converting = 1;
-	if( $date =~ m{/}) {
-	    ($mon,$mday,$year) = split(m{/}, $date);
-	} elsif($date =~ /(\d{4})-(\d{1,2})-(\d{1,2})/) {
-	    ($year,$mon,$mday) = ($1, $2, $3);
-	} elsif($date =~ /(\d{4})-(\w{3,})-(\d{1,2})/) {
-	    ($year,$mon,$mday) = ($1, $2, $3);
-	    $mon = $self->month2num($2);
-	} else {
-	    print STDERR "\n*** Unsupported input date format: $date\n";
-	}
-	if(length($year) == 4) { 
+        if( $date =~ m{/}) {
+            ($mon,$mday,$year) = split(m{/}, $date);
+        } elsif($date =~ /(\d{4})-(\d{1,2})-(\d{1,2})/) {
+            ($year,$mon,$mday) = ($1, $2, $3);
+        } elsif($date =~ /(\d{4})-(\w{3,})-(\d{1,2})/) {
+            ($year,$mon,$mday) = ($1, $2, $3);
+            $mon = $self->month2num($2);
+        } else {
+            print STDERR "\n*** Unsupported input date format: $date\n";
+        }
+        if(length($year) == 4) {
             $fullYear = $year;
-            $year = substr $year, 2; 
+            $year = substr $year, 2;
         } else {
             # Heuristics to guess what century was intended when a 2-digit year is given
             # If number is over 50, assume it's for prev century; under 50 = default century.
@@ -272,11 +217,11 @@ sub date_format {
                 $fullYear = $DEFAULT_CENTURY + $year;
             }
         }
-	$mon -= 1;
+        $mon -= 1;
     } else {
-	($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = @date =
-	    localtime(($date ? $date : time()));
-	return @date if $option =~ /list/i;
+        ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = @date =
+            localtime(($date ? $date : time()));
+        return @date if $option =~ /list/i;
         $fullYear = $BASE_YEAR+$year;
     }
     $month_txt = $MONTHS[$mon];
@@ -286,36 +231,36 @@ sub date_format {
 #    print "sec: $sec, min: $min, hour: $hour, month: $mon, m-day: $mday, year: $year\nwday: $wday, yday: $yday, dst: $isdst";<STDIN>;
 
     if( $option =~ /yyyy-mm-dd/i ) {
-	$date = sprintf "%4d-%02d-%02d",$fullYear,$month_num,$mday;
+        $date = sprintf "%4d-%02d-%02d",$fullYear,$month_num,$mday;
     } elsif( $option =~ /yyyy-dd-mm/i ) {
-	$date = sprintf "%4d-%02d-%02d",$fullYear,$mday,$month_num;
+        $date = sprintf "%4d-%02d-%02d",$fullYear,$mday,$month_num;
     } elsif( $option =~ /yyyy-mmm-dd/i ) {
-	$date = sprintf "%4d-%3s-%02d",$fullYear,$month_txt,$mday;
+        $date = sprintf "%4d-%3s-%02d",$fullYear,$month_txt,$mday;
     } elsif( $option =~ /full|unix/i ) {
-	$date = sprintf "%3s %3s %2d %02d:%02d:%02d %d",$day_txt, $month_txt, $mday, $hour, $min, $sec, $fullYear;
+        $date = sprintf "%3s %3s %2d %02d:%02d:%02d %d",$day_txt, $month_txt, $mday, $hour, $min, $sec, $fullYear;
     } elsif( $option =~ /mdy/i ) {
-	$date = "$month_txt $mday, $fullYear";
+        $date = "$month_txt $mday, $fullYear";
     } elsif( $option =~ /ymd/i ) {
-	$date = $year."\l$month_txt$mday";
+        $date = $year."\l$month_txt$mday";
     } elsif( $option =~ /dmy/i ) {
-	$date = $mday."\l$month_txt$year";
+        $date = $mday."\l$month_txt$year";
     } elsif( $option =~ /md/i ) {
-	$date = "\l$month_txt$mday";
+        $date = "\l$month_txt$mday";
     } elsif( $option =~ /d-m-y/i ) {
-	$date = "$mday-$month_txt-$fullYear";
+        $date = "$mday-$month_txt-$fullYear";
     } elsif( $option =~ /d m y/i ) {
-	$date = "$mday $month_txt $fullYear";
+        $date = "$mday $month_txt $fullYear";
     } elsif( $option =~ /year/i ) {
-	$date = $fullYear;
+        $date = $fullYear;
     } elsif( $option =~ /dmy/i ) {
-	$date = $mday.'-'.$month_txt.'-'.$fullYear;
+        $date = $mday.'-'.$month_txt.'-'.$fullYear;
     } elsif($option and $option !~ /hms/i) {
-	print STDERR "\n*** Unrecognized date format request: $option\n";
+        print STDERR "\n*** Unrecognized date format request: $option\n";
     }
 
     if( $option =~ /hms/i and not $converting) {
-	$date .= " $hour:$min:$sec" if $date;
-	$date ||= "$hour:$min:$sec";
+        $date .= " $hour:$min:$sec" if $date;
+        $date ||= "$hour:$min:$sec";
     }
 
     return $date || join(" ", @date);
@@ -337,13 +282,12 @@ sub date_format {
 #--------------'
 sub month2num {
 #--------------
-
     my ($self, $str) = @_;
 
     # Get string in proper format for conversion.
     $str = substr($str, 0, 3);
-    for(0..$#MONTHS) {
-	return $_+1 if $str =~ /$MONTHS[$_]/i;
+    for my $month (0..$#MONTHS) {
+        return $month+1 if $str =~ /$MONTHS[$month]/i;
     }
     $self->throw("Invalid month name: $str");
 }
@@ -390,17 +334,17 @@ sub num2month {
            :            gzip, which is the default)
            :   -OUTFILE => String (name of the output compressed file, full path).
            :   -EXE  => Name of executable for compression utility to use.
-           :            Will supercede those in @COMPRESSION_UTILS defined by 
+           :            Will supercede those in @COMPRESSION_UTILS defined by
            :            this module. If the absolute path to the executable is not provided,
            :            it will be searched in the PATH env variable.
  Throws    : Exception if file cannot be compressed.
            : If user is not owner of the file, generates a warning and compresses to
-           : a tmp file. To avoid this warning, use the -o file test operator 
+           : a tmp file. To avoid this warning, use the -o file test operator
            : and call this function with -TMP=>1.
- Comments  : Attempts to compress using utilities defined in the @COMPRESSION_UTILS 
-           : defined by this module, in the order defined. The first utility that is 
+ Comments  : Attempts to compress using utilities defined in the @COMPRESSION_UTILS
+           : defined by this module, in the order defined. The first utility that is
            : found to be executable will be used. Any utility defined in optional -EXE param
-           : will be tested for executability first. 
+           : will be tested for executability first.
            : To minimize security risks, the -EXE parameter value is untained using
            : the untaint() method of this module (in 'relaxed' mode to permit path separators).
 
@@ -451,14 +395,19 @@ sub compress {
             $compressed .= '.tmp.bioperl.gz';
         }
 
+        # Use double quotes if executable path have empty spaces
+        if ($exe =~ m/ /) {
+            $exe = "\"$exe\"";
+        }
+
         if ($exe =~ /gzip|bzip2|compress/) {
             @cmd = ("$exe -f < \"$fileName\" > \"$compressed\"");
         } elsif ($exe eq 'zip') {
             @cmd = ("$exe -r \"$fileName.zip\" \"$fileName\"");
         }
-	not $tmp and
-	    $self->warn("Not owner of file $fileName. Compressing to temp file $compressed.");
-	$tmp = 1;
+        not $tmp and
+            $self->warn("Not owner of file $fileName. Compressing to temp file $compressed.");
+        $tmp = 1;
     } else {
         # Need to compute the compressed name based on exe since we're returning it.
         $compressed = $fileName;
@@ -509,17 +458,17 @@ sub compress {
            :            gzip, which is the default)
            :   -OUTFILE => String (name of the output uncompressed file, full path).
            :   -EXE  => Name of executable for uncompression utility to use.
-           :            Will supercede those in @UNCOMPRESSION_UTILS defined by 
+           :            Will supercede those in @UNCOMPRESSION_UTILS defined by
            :            this module. If the absolute path to the executable is not provided,
            :            it will be searched in the PATH env variable.
  Throws    : Exception if file cannot be uncompressed.
            : If user is not owner of the file, generates a warning and uncompresses to
-           : a tmp file. To avoid this warning, use the -o file test operator 
+           : a tmp file. To avoid this warning, use the -o file test operator
            : and call this function with -TMP=>1.
- Comments  : Attempts to uncompress using utilities defined in the @UNCOMPRESSION_UTILS 
-           : defined by this module, in the order defined. The first utility that is 
+ Comments  : Attempts to uncompress using utilities defined in the @UNCOMPRESSION_UTILS
+           : defined by this module, in the order defined. The first utility that is
            : found to be executable will be used. Any utility defined in optional -EXE param
-           : will be tested for executability first. 
+           : will be tested for executability first.
            : To minimize security risks, the -EXE parameter value is untained using
            : the untaint() method of this module (in 'relaxed' mode to permit path separators).
 
@@ -572,17 +521,26 @@ sub uncompress {
             $uncompressed .= '.tmp.bioperl';
         }
 
+        # Use double quotes if executable path have empty spaces
+        if ($exe =~ m/ /) {
+            $exe = "\"$exe\"";
+        }
+
         if ($exe =~ /gunzip|bunzip2|uncompress/) {
             @cmd = ("$exe -f < \"$fileName\" > \"$uncompressed\"");
+        } elsif ($exe =~ /gzip/) {
+            @cmd = ("$exe -df < \"$fileName\" > \"$uncompressed\"");
         } elsif ($exe eq 'unzip') {
             @cmd = ("$exe -p \"$fileName\" > \"$uncompressed\"");
         }
-	not $tmp and
-	    $self->warn("Not owner of file $fileName. Uncompressing to temp file $uncompressed.");
-	$tmp = 1;
+        not $tmp and
+            $self->warn("Not owner of file $fileName. Uncompressing to temp file $uncompressed.");
+        $tmp = 1;
     } else {
         if ($exe =~ /gunzip|bunzip2|uncompress/) {
             @cmd = ($exe, '-f', $fileName);
+        } elsif ($exe =~ /gzip/) {
+            @cmd = ($exe, '-df', $fileName);
         } elsif ($exe eq 'zip') {
             @cmd = ($exe, $fileName);
         }
@@ -663,14 +621,14 @@ sub untaint {
     }
 
     if( $relax ) {
-	$value =~ /([-\w.\', ()\/=%:^<>*]+)/;
-	$untainted = $1
+        $value =~ /([-\w.\', ()\/=%:^<>*]+)/;
+        $untainted = $1
 #    } elsif( $relax == 2 ) {  # Could have several degrees of relax.
-#	$value =~ /([-\w.\', ()\/=%:^<>*]+)/;
-#	$untainted = $1
+#        $value =~ /([-\w.\', ()\/=%:^<>*]+)/;
+#        $untainted = $1
     } else {
-	$value =~ /([-\w.\', ()]+)/;
-	$untainted = $1
+        $value =~ /([-\w.\', ()]+)/;
+        $untainted = $1
     }
 
     $self->debug("UNTAINTED: $untainted\n");
@@ -694,13 +652,18 @@ sub untaint {
 sub mean_stdev {
 #---------------
     my ($self, @data) = @_;
-    return (undef,undef) if not @data; # case of empty @data list
+    return (undef, undef) if not @data; # case of empty @data list
     my $mean = 0;
     my $N = 0;
-    foreach (@data) { $mean += $_; $N++ }
+    foreach my $num (@data) {
+        $mean += $num;
+        $N++
+    }
     $mean /= $N;
     my $sum_diff_sqd = 0;
-    foreach (@data) { $sum_diff_sqd += ($mean - $_) * ($mean - $_); }
+    foreach my $num (@data) {
+        $sum_diff_sqd += ($mean - $num) * ($mean - $num);
+    }
     # if only one element in @data list, unbiased stdev is undefined
     my $stdev = $N <= 1 ? undef : sqrt( $sum_diff_sqd / ($N-1) );
     return ($mean, $stdev);
@@ -749,35 +712,38 @@ sub count_files {
     $$href{-T_FILE_NAMES} = [];
     $$href{-B_FILE_NAMES} = [];
     $$href{-DIR_NAMES} = [];
-    while( <$PIPE> ) {
-	chomp();
-	$$href{-TOTAL}++;
-	if( -T $dir.$_ ) {
-	    $$href{-NUM_TEXT_FILES}++; push @{$$href{-T_FILE_NAMES}}, $_; }
-	if( -B $dir.$_ and not -d $dir.$_) {
-	    $$href{-NUM_BINARY_FILES}++; push @{$$href{-B_FILE_NAMES}}, $_; }
-	if( -d $dir.$_ ) {
-	    $$href{-NUM_DIRS}++; push @{$$href{-DIR_NAMES}}, $_; }
+    while( my $line = <$PIPE> ) {
+        chomp();
+        $$href{-TOTAL}++;
+        if( -T $dir.$line ) {
+            $$href{-NUM_TEXT_FILES}++;
+            push @{$$href{-T_FILE_NAMES}}, $line; }
+        if( -B $dir.$line and not -d $dir.$line) {
+            $$href{-NUM_BINARY_FILES}++;
+            push @{$$href{-B_FILE_NAMES}}, $line; }
+        if( -d $dir.$line ) {
+            $$href{-NUM_DIRS}++;
+            push @{$$href{-DIR_NAMES}}, $line; }
     }
     close $PIPE;
 
     if( $print) {
-	printf( "\n%4d %s\n", $$href{-TOTAL}, "total files+dirs in $dir");
-	printf( "%4d %s\n", $$href{-NUM_TEXT_FILES}, "text files");
-	printf( "%4d %s\n", $$href{-NUM_BINARY_FILES}, "binary files");
-	printf( "%4d %s\n", $$href{-NUM_DIRS}, "directories");
+        printf( "\n%4d %s\n", $$href{-TOTAL},            "total files+dirs in $dir");
+        printf( "%4d %s\n",   $$href{-NUM_TEXT_FILES},   "text files");
+        printf( "%4d %s\n",   $$href{-NUM_BINARY_FILES}, "binary files");
+        printf( "%4d %s\n",   $$href{-NUM_DIRS},         "directories");
     }
 }
 
 
-#=head2 file_info
-#
-# Title   : file_info
-# Purpose : Obtains a variety of date for a given file.
-#	  : Provides an interface to Perl's stat().
-# Status  : Under development. Not ready. Don't use!
-#
-#=cut
+=head2 file_info
+
+ Title   : file_info
+ Purpose : Obtains a variety of date for a given file.
+         : Provides an interface to Perl's stat().
+ Status  : Under development. Not ready. Don't use!
+
+=cut
 
 #--------------
 sub file_info {
@@ -791,33 +757,39 @@ sub file_info {
        $atime, $mtime, $ctime, $blksize, $blocks) = stat $file;
 
     if($get =~ /date/i) {
-	## I can  get the elapsed time since the file was modified but
-	## it's not so straightforward to get the date in a nice format...
+        ## I can  get the elapsed time since the file was modified but
+        ## it's not so straightforward to get the date in a nice format...
         ## Think about using a standard CPAN module for this, like
         ## Date::Manip or Date::DateCalc.
 
-	my $date = $mtime;
-	my $elsec = time - $mtime;
-	printf "\nFile age: %.0f sec %.0f hrs %.0f days", $elsec, $elsec/3600, $elsec/(3600*24);<STDIN>;
-	my $days = sprintf "%.0f", $elsec/(3600*24);
+        my $date = $mtime;
+        my $elsec = time - $mtime;
+        printf "\nFile age: %.0f sec %.0f hrs %.0f days", $elsec, $elsec/3600, $elsec/(3600*24);<STDIN>;
+        my $days = sprintf "%.0f", $elsec/(3600*24);
     } elsif($get eq 'all') {
-	return stat $file;
+        return stat $file;
     }
 }
 
+=head2 delete
+
+ Title   : delete
+ Purpose :
+
+=cut
 
 #------------
 sub delete {
 #------------
-  my $self = shift;
-  my $fileName = shift;
-  if(not -e $fileName) {
-    $self->throw("Can't delete file $fileName: Does not exist.");
-  } elsif(not -o $fileName) {
-    $self->throw("Can't delete file $fileName: Not owner.");
-  }
-  my $ulval = unlink($fileName) > 0 or
-    $self->throw("Failed to delete file $fileName: $!");
+    my $self = shift;
+    my $fileName = shift;
+    if(not -e $fileName) {
+        $self->throw("Could not delete file '$fileName': Does not exist.");
+    } elsif(not -o $fileName) {
+        $self->throw("Could not delete file '$fileName': Not owner.");
+    }
+    my $ulval = unlink($fileName) > 0
+        or $self->throw("Failed to delete file '$fileName': $!");
 }
 
 
@@ -854,55 +826,55 @@ sub create_filehandle {
 #---------------------
     my($self, @param) = @_;
     my($client, $file, $handle) =
-	$self->_rearrange([qw( CLIENT FILE HANDLE )], @param);
+        $self->_rearrange([qw( CLIENT FILE HANDLE )], @param);
 
     if(not ref $client) {  $client = $self; }
     $file ||= $handle;
     if( $client->can('file')) {
-	$file = $client->file($file);
+        $file = $client->file($file);
     }
 
     my $FH;
     my ($handle_ref);
 
     if($handle_ref = ref($file)) {
-      if($handle_ref eq 'FileHandle') {
-	$FH = $file;
-	$client->{'_input_type'} = "FileHandle";
-      } elsif($handle_ref eq 'GLOB') {
-	$FH = $file;
-	$client->{'_input_type'} = "Glob";
-      } else {
-        $self->throw(-class=>'Bio::Root::IOException',
-                     -text =>"Can't read from $file: Not a FileHandle or GLOB ref.");
-      }
-      $self->verbose > 0 and printf STDERR "$ID: reading data from FileHandle\n";
+        if($handle_ref eq 'FileHandle') {
+            $FH = $file;
+            $client->{'_input_type'} = "FileHandle";
+        } elsif($handle_ref eq 'GLOB') {
+            $FH = $file;
+            $client->{'_input_type'} = "Glob";
+        } else {
+            $self->throw(-class => 'Bio::Root::IOException',
+                         -text  => "Could not read file '$file': Not a FileHandle or GLOB ref.");
+        }
+        $self->verbose > 0 and printf STDERR "$ID: reading data from FileHandle\n";
 
     } elsif($file) {
-      $client->{'_input_type'} = "FileHandle for $file";
+        $client->{'_input_type'} = "FileHandle for $file";
 
-      # Use gzip -cd to access compressed data.
-      if( -B $file ) {
-	$client->{'_input_type'} .= " (compressed)";
-        my $gzip = $self->find_exe('gzip');
-	$file = "$gzip -cd $file |"
-      }
+        # Use gzip -cd to access compressed data.
+        if( -B $file ) {
+            $client->{'_input_type'} .= " (compressed)";
+            my $gzip = $self->find_exe('gzip');
+            $file = "$gzip -cd $file |"
+        }
 
-      require FileHandle;
-      $FH = new FileHandle;
-      open ($FH, $file) || $self->throw(-class=>'Bio::Root::FileOpenException',
-                                        -text =>"Can't access data file: $file: $!");
-      $self->verbose > 0 and printf STDERR "$ID: reading data from file $file\n";
+        require FileHandle;
+        $FH = FileHandle->new();
+        open ($FH, $file) || $self->throw(-class=>'Bio::Root::FileOpenException',
+                                          -text =>"Could not access data file '$file': $!");
+        $self->verbose > 0 and printf STDERR "$ID: reading data from file '$file'\n";
 
     } else {
-      # Read from STDIN.
-      $FH = \*STDIN;
-      $self->verbose > 0 and printf STDERR "$ID: reading data from STDIN\n";
-      $client->{'_input_type'} = "STDIN";
+        # Read from STDIN.
+        $FH = \*STDIN;
+        $self->verbose > 0 and printf STDERR "$ID: reading data from STDIN\n";
+        $client->{'_input_type'} = "STDIN";
     }
 
     return $FH;
-  }
+}
 
 =head2 get_newline
 
@@ -927,24 +899,24 @@ sub get_newline {
     return $NEWLINE if defined $NEWLINE;
 
     my($client ) =
-	$self->_rearrange([qw( CLIENT )], @param);
+        $self->_rearrange([qw( CLIENT )], @param);
 
     my $FH = $self->create_filehandle(@param);
 
     if(not ref $client) {  $client = $self;   }
 
     if($client->{'_input_type'} =~ /STDIN|Glob|compressed/) {
-      # Can't taste from STDIN since we can't seek 0 on it.
-      # Are other non special Glob refs seek-able?
-      # Attempt to guess newline based on platform.
-      # Not robust since we could be reading Unix files on a Mac, e.g.
-      if(defined $ENV{'MACPERL'}) {
-	$NEWLINE = "\015";  # \r
-      } else {
-	$NEWLINE = "\012";  # \n
-      }
+        # Can't taste from STDIN since we can't seek 0 on it.
+        # Are other non special Glob refs seek-able?
+        # Attempt to guess newline based on platform.
+        # Not robust since we could be reading Unix files on a Mac, e.g.
+        if(defined $ENV{'MACPERL'}) {
+            $NEWLINE = "\015";  # \r
+        } else {
+            $NEWLINE = "\012";  # \n
+        }
     } else {
-      $NEWLINE = $self->taste_file($FH);
+        $NEWLINE = $self->taste_file($FH);
     }
 
     close ($FH) unless ($client->{'_input_type'} eq 'STDIN' ||
@@ -954,7 +926,7 @@ sub get_newline {
     delete $client->{'_input_type'};
 
     return $NEWLINE || $DEFAULT_NEWLINE;
-  }
+}
 
 
 =head2 taste_file
@@ -980,80 +952,81 @@ See Also : L<get_newline()|get_newline>
 #---------------
 sub taste_file {
 #---------------
-  my ($self, $FH) = @_;
-  my $BUFSIZ = 256;   # Number of bytes read from the file handle.
-  my ($buffer, $octal, $str, $irs, $i);
+    my ($self, $FH) = @_;
+    my $BUFSIZ = 256;   # Number of bytes read from the file handle.
+    my ($buffer, $octal, $str, $irs, $i);
 
-  ref($FH) eq 'FileHandle' or $self->throw("Can't taste file: not a FileHandle ref");
+    ref($FH) eq 'FileHandle' or $self->throw("Can't taste file: not a FileHandle ref");
 
-  $buffer = '';
+    $buffer = '';
 
-  # this is a quick hack to check for availability of alarm(); just copied
-  # from Bio/Root/IOManager.pm HL 02/19/01
-  my $alarm_available = 1;
-  eval {
-      alarm(0);
-  };
-  if($@) {
-      # alarm() not available (ActiveState perl for win32 doesn't have it.
-      # See jitterbug PR#98)
-      $alarm_available = 0;
-  }
-  $SIG{ALRM} = sub { die "Timed out!"; };
-  my $result;
-  eval {
-    $alarm_available && alarm( $TIMEOUT_SECS );
-    $result = read($FH, $buffer, $BUFSIZ); # read the $BUFSIZ characters of file
-    $alarm_available && alarm(0);
-  };
-  if($@ =~ /Timed out!/) {
-    $self->throw("Timed out while waiting for input.",
-		 "Timeout period = $TIMEOUT_SECS seconds.\nFor longer time before timing out, edit \$TIMEOUT_SECS in Bio::Root::Utilities.pm.");
-
-  } elsif(not $result) {
-    my $err = $@;
-    $self->throw("read taste failed to read from FileHandle.", $err);
-
-  } elsif($@ =~ /\S/) {
-    my $err = $@;
-    $self->throw("Unexpected error during read: $err");
-  }
-
-  seek($FH, 0, 0) or $self->throw("seek failed to seek 0 on FileHandle.");
-
-  my @chars = split(//, $buffer);
-  my $flavor;
-
-  for ($i = 0; $i <$BUFSIZ; $i++) {
-    if (($chars[$i] eq "\012")) {
-      unless ($chars[$i-1] eq "\015") {
-	$flavor='Unix';
-	$octal = "\012";
-	$str = '\n';
-	$irs = "^J";
-	last;
-      }
-    } elsif (($chars[$i] eq "\015") && ($chars[$i+1] eq "\012")) {
-      $flavor='DOS';
-      $octal = "\015\012";
-      $str = '\r\n';
-      $irs = "^M^J";
-      last;
-    } elsif (($chars[$i] eq "\015")) {
-      $flavor='Mac';
-      $octal = "\015";
-      $str = '\r';
-      $irs = "^M";
-      last;
+    # this is a quick hack to check for availability of alarm(); just copied
+    # from Bio/Root/IOManager.pm HL 02/19/01
+    my $alarm_available = 1;
+    eval {
+        alarm(0);
+    };
+    if($@) {
+        # alarm() not available (ActiveState perl for win32 doesn't have it.
+        # See jitterbug PR#98)
+        $alarm_available = 0;
     }
-  }
-  if (not $octal) {
-    $self->warn("Could not determine newline char. Using '\012'");
-    $octal = "\012";
-  } else {
-#    print STDERR "FLAVOR=$flavor, NEWLINE CHAR = $irs\n";
-  }
-  return($octal);
+    $SIG{ALRM} = sub { die "Timed out!"; };
+    my $result;
+    eval {
+        $alarm_available && alarm( $TIMEOUT_SECS );
+        $result = read($FH, $buffer, $BUFSIZ); # read the $BUFSIZ characters of file
+        $alarm_available && alarm(0);
+    };
+    if($@ =~ /Timed out!/) {
+        $self->throw( "Timed out while waiting for input.",
+                      "Timeout period = $TIMEOUT_SECS seconds.\n"
+                     ."For longer time before timing out, edit \$TIMEOUT_SECS in Bio::Root::Utilities.pm.");
+
+    } elsif(not $result) {
+        my $err = $@;
+        $self->throw("read taste failed to read from FileHandle.", $err);
+
+    } elsif($@ =~ /\S/) {
+        my $err = $@;
+        $self->throw("Unexpected error during read: $err");
+    }
+
+    seek($FH, 0, 0) or $self->throw("seek failed to seek 0 on FileHandle.");
+
+    my @chars = split(//, $buffer);
+    my $flavor;
+
+    for ($i = 0; $i <$BUFSIZ; $i++) {
+        if (($chars[$i] eq "\012")) {
+            unless ($chars[$i-1] eq "\015") {
+                $flavor='Unix';
+                $octal = "\012";
+                $str = '\n';
+                $irs = "^J";
+                last;
+            }
+        } elsif (($chars[$i] eq "\015") && ($chars[$i+1] eq "\012")) {
+            $flavor='DOS';
+            $octal = "\015\012";
+            $str = '\r\n';
+            $irs = "^M^J";
+            last;
+        } elsif (($chars[$i] eq "\015")) {
+            $flavor='Mac';
+            $octal = "\015";
+            $str = '\r';
+            $irs = "^M";
+            last;
+        }
+    }
+    if (not $octal) {
+        $self->warn("Could not determine newline char. Using '\012'");
+        $octal = "\012";
+    } else {
+        #print STDERR "FLAVOR=$flavor, NEWLINE CHAR = $irs\n";
+    }
+    return($octal);
 }
 
 =head2 file_flavor
@@ -1084,7 +1057,7 @@ sub file_flavor {
                  "\015"     =>'mac (\r or 015 or ^M)'
                 );
 
-    -f $file or $self->throw("Can't determine flavor: arg '$file' is either non existant or is not a file.\n");
+    -f $file or $self->throw("Could not determine flavor: arg '$file' is either non existant or is not a file.\n");
     my $octal = $self->get_newline($file);
     my $flavor = $flavors{$octal} || "unknown";
     return $flavor;
@@ -1104,8 +1077,9 @@ See Also  : L<send_mail()|send_mail>
 
 =cut
 
+#---------------
 sub mail_authority {
-
+#---------------
     my( $self, $message ) = @_;
     my $script = $self->untaint($0,1);
 
@@ -1127,8 +1101,9 @@ See Also  : L<mail_authority()|mail_authority>
 
 =cut
 
+#-------------
 sub authority {
-
+#-------------
     my( $self, $email ) = @_;
     $self->{'_auth_email'} = $email if defined $email;
     return $self->{'_auth_email'};
@@ -1163,14 +1138,14 @@ See Also  : L<mail_authority()|mail_authority>
 =cut
 
 
-#-------------'
+#-------------
 sub send_mail {
 #-------------
     my( $self, @param) = @_;
     my($recipient,$subj,$message,$cc) = $self->_rearrange([qw(TO SUBJ MSG CC)],@param);
 
     $self->throw("Invalid or missing e-mail address: $recipient")
-	if not $recipient =~ /\S+\@\S+/;
+        if not $recipient =~ /\S+\@\S+/;
 
     $subj ||= 'empty subject'; $message ||= '';
 
@@ -1231,14 +1206,26 @@ See Also   :
 
 =cut
 
+#------------
 sub find_exe {
+#------------
     my ($self, $name) = @_;
-    my @bindirs = split (':', $ENV{'PATH'});
+    my @bindirs;
+    if ($^O =~ m/mswin/i) {
+        @bindirs = split ';', $ENV{'PATH'};
+        # Add usual executable extension if missing or -x won't work
+        $name.= '.exe' if ($name !~ m/\.exe$/i);
+    }
+    else {
+        @bindirs = split ':', $ENV{'PATH'};
+    }
     my $exe = $name;
     unless (-x $exe) {
         undef $exe;
         my @exes;
         foreach my $d (@bindirs) {
+            # Note: Windows also understand '/' as folder separator,
+            # so there is no need to use a conditional with '\'
             push(@exes, "$d/$name") if -x "$d/$name";
         }
         if (scalar @exes) {
@@ -1310,6 +1297,14 @@ sub request_data {
     $data;
 }
 
+=head2 quit_reply
+
+ Title   : quit_reply
+ Usage   :
+ Purpose :
+
+=cut
+
 sub quit_reply {
 # Not much used since you can use request_data()
 # and test for an empty string.
@@ -1335,16 +1330,12 @@ sub verify_version {
     my $reqVersion  = shift;
 
     $] < $reqVersion and do {
-	printf STDERR ( "\a\n%s %0.3f.\n", "** Sorry. This Perl script requires at least version", $reqVersion);
-	printf STDERR ( "%s %0.3f %s\n\n", "You are running Perl version", $], "Please update your Perl!\n\n" );
-	exit(1);
+        printf STDERR ( "\a\n%s %0.3f.\n", "** Sorry. This Perl script requires at least version", $reqVersion);
+        printf STDERR ( "%s %0.3f %s\n\n", "You are running Perl version", $], "Please update your Perl!\n\n" );
+        exit(1);
     }
 }
 
-
 1;
 
-
 __END__
-
-
