@@ -166,7 +166,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution.  Bug reports can be submitted via the
 web:
 
-  https://redmine.open-bio.org/projects/bioperl/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Heikki Lehvaslaiho
 
@@ -220,7 +220,8 @@ BEGIN {
      '', '',  '', '',
      'Trematode Mitochondrial',# 21
      'Scenedesmus obliquus Mitochondrial', #22
-     'Thraustochytrium Mitochondrial' #23
+     'Thraustochytrium Mitochondrial', #23
+     'Strict', #24, option for only ATG start
      );
 
     @TABLES =
@@ -244,6 +245,7 @@ BEGIN {
        FFLLSSSSYY**CCWWLLLLPPPPHHQQRRRRIIMMTTTTNNNKSSSSVVVVAAAADDEEGGGG
        FFLLSS*SYY*LCC*WLLLLPPPPHHQQRRRRIIIMTTTTNNKKSSRRVVVVAAAADDEEGGGG
        FF*LSSSSYY**CC*WLLLLPPPPHHQQRRRRIIIMTTTTNNKKSSRRVVVVAAAADDEEGGGG
+       FFLLSSSSYY**CC*WLLLLPPPPHHQQRRRRIIIMTTTTNNKKSSRRVVVVAAAADDEEGGGG
        );
 
    #           (bases used for these tables, for reference)
@@ -272,6 +274,7 @@ BEGIN {
        -----------------------------------M---------------M------------
        -----------------------------------M----------------------------
        --------------------------------M--M---------------M------------
+       -----------------------------------M----------------------------
        );
 
     my @nucs = qw(t c a g);
