@@ -49,7 +49,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution.  Bug reports can be submitted via 
 the web:
 
-  https://redmine.open-bio.org/projects/bioperl/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Peter Schattner
 
@@ -113,7 +113,7 @@ Some of the most commonly used parameters are listed below. All
 parameters have defaults and are optional except for -p in those programs that
 have it. For a complete listing of settable parameters, run the relevant
 executable BLAST program with the option "-" as in blastall -
-Note that the input paramters (-i, -j, -input) should not be set directly by
+Note that the input parameters (-i, -j, -input) should not be set directly by
 you: this module sets them when you call one of the executable methods.
 
 Blastall
@@ -431,6 +431,10 @@ sub _runblast {
 		return;
 	}
     
+    # Use double quotes if executable path have empty spaces
+    if ($exe =~ m/ /) {
+        $exe = "\"$exe\"";
+    }
 	my $commandstring = $exe.$param_string;
     
 	$self->debug("$commandstring\n");
