@@ -1,7 +1,8 @@
-# $Id: SeqStats.pm 15082 2008-12-03 14:14:15Z bosborne $
 #
 # BioPerl module for Bio::Tools::SeqStats
 #
+# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+#
 # Cared for by
 #
 # Copyright Peter Schattner
@@ -179,12 +180,23 @@ of the Bioperl mailing lists.  Your participation is much appreciated.
   bioperl-l@bioperl.org                  - General discussion
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
+=head2 Support 
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
+
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution.  Bug reports can be submitted the web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Peter Schattner
 
@@ -559,16 +571,20 @@ sub get_mol_wt {
 	my $weight_lower_bound = 0;
 	my $weight_upper_bound = 0;
 	my $weight_table =  $Weights{$moltype};
-
+    my $total_res;
+    
 	# compute weight of all the residues
 	foreach $element (keys %$rcount) {
 		$weight_lower_bound += $$rcount{$element} * $$weight_table{$element}->[0];
 		$weight_upper_bound += $$rcount{$element} * $$weight_table{$element}->[1];
+        
+        # this tracks only the residues used for counting MW
+        $total_res += $$rcount{$element};
 	}
 	if ($moltype =~ /protein/) {
-    	# remove H2O during peptide bond formation.
-    	$weight_lower_bound -= $water * ($seqobj->length - 1);
-    	$weight_upper_bound -= $water * ($seqobj->length - 1);
+        # remove H2O during peptide bond formation.
+    	$weight_lower_bound -= $water * ($total_res - 1);
+    	$weight_upper_bound -= $water * ($total_res - 1);
 	} else {
     	# Correction because phosphate of 5' residue has additional OH and
     	# sugar ring of 3' residue has additional H
