@@ -1,7 +1,8 @@
-# $Id: Node.pm 15170 2008-12-16 03:25:40Z cjfields $
 #
 # BioPerl module for Bio::Tree::Node
 #
+# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+#
 # Cared for by Jason Stajich <jason-at-bioperl.org>
 #
 # Copyright Jason Stajich
@@ -42,13 +43,24 @@ the Bioperl mailing list.  Your participation is much appreciated.
   bioperl-l@bioperl.org                  - General discussion
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
+=head2 Support 
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
+
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via
 the web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Jason Stajich
 
@@ -73,8 +85,6 @@ package Bio::Tree::Node;
 use vars qw($CREATIONORDER);
 use strict;
 
-use Scalar::Util qw(weaken isweak);
-
 use base qw(Bio::Root::Root Bio::Tree::NodeI);
 
 BEGIN {
@@ -125,7 +135,7 @@ sub new {
   defined $branchlen && $self->branch_length($branchlen);
   if( defined $children ) {
       if( ref($children) !~ /ARRAY/i ) {
-	  $self->warn("Must specify a valid ARRAY reference to initialize a Node's Descendents");
+	  $self->throw("Must specify a valid ARRAY reference to initialize a Node's Descendents");
       }
       foreach my $c ( @$children ) { 	
 	  $self->add_Descendent($c);
@@ -135,6 +145,65 @@ sub new {
   return $self;
 }
 
+=head2 create_node_on_branch
+
+ Title   : create_node_on_branch
+ Usage   : $node->create_node_on_branch($at_length)
+ Function: Create a node on the ancestral branch of the calling
+           object. 
+ Example :
+ Returns : the created node
+ Args    : -POSITION=>$absolute_branch_length_from_caller (default)
+           -FRACTION=>$fraction_of_branch_length_from_caller
+           -ANNOT=>{ -id => "the id", -desc => "the description" }
+           -FORCE, set to allow nodes with zero branch lengths
+
+=cut
+
+sub create_node_on_branch{
+   my ($self,@args) = @_;
+   my ($pos, $frac, $annot, $force) = $self->_rearrange([qw(POSITION FRACTION ANNOT FORCE)], @args);
+   my ($newpos);
+   my $blen = $self->branch_length;
+   # arg checks
+   $force||=0;
+   $annot||={};
+
+   unless ($self->ancestor) {
+       $self->throw("Refusing to create nodes above the root--exiting");
+   }
+   unless ($blen) {
+       $self->throw("Calling node's branch length is zero") unless $force;
+   }
+   unless ((defined $pos && !defined $frac)||(defined $frac && !defined $pos)) {
+       $self->throw("Either position or fraction must be specified, but not both");
+   }
+   if (defined $frac) {
+       $self->throw("FRACTION arg must be in the range [0,1]") unless ( (0 <= $frac) && ($frac <= 1) );
+       $newpos = $frac*$blen;
+   }
+   elsif (defined $pos) {
+       $self->throw("POSITION arg must be in the range [0,$blen]") unless ( (0 <= $pos) && ($pos <= $blen) );
+       $newpos = $pos;
+   }
+   else {
+       $self->throw("How did I get here?");
+   }
+   $self->throw("Calling node's branch length will be zero (set -FORCE to force)--exiting") unless ($newpos > 0) || $force;
+   $self->throw("Created nodes branch length would be zero (set -FORCE to force)--exiting") unless ($newpos < $blen) || $force;
+
+   #guts
+   $annot->{'-branch_length'} = $blen-$newpos;
+   my $node = Bio::Tree::Node->new(%$annot);
+   my $anc = $self->ancestor;
+   # null anc check is above
+   $node->add_Descendent($self);
+   $anc->add_Descendent($node);
+   $anc->remove_Descendent($self);
+   $self->branch_length($newpos);
+   return $node;
+}
+
 =head2 add_Descendent
 
  Title   : add_Descendent
@@ -234,6 +303,7 @@ sub each_Descendent{
        return map { $_->[0] }
        sort { $a->[1] <=> $b->[1] } 
        map { [$_, $_->internal_id ] }
+       grep {defined $_}
        values %{$self->{'_desc'}};	   
    }
 }
@@ -241,7 +311,7 @@ sub each_Descendent{
 =head2 remove_Descendent
 
  Title   : remove_Descendent
- Usage   : $node->remove_Descedent($node_foo);
+ Usage   : $node->remove_Descendent($node_foo);
  Function: Removes a specific node from being a Descendent of this node
  Returns : nothing
  Args    : An array of Bio::Node::NodeI objects which have been previously
@@ -268,19 +338,6 @@ sub remove_Descendent{
 	   }
        }
    }
-   
-   # remove unecessary nodes if we have removed the part 
-   # which branches.
-   my $a1 = $self->ancestor;   
-   if( $a1 ) {
-       my $bl = $self->branch_length || 0;
-       my @d = $self->each_Descendent;
-       if (scalar @d == 1) {
-	   $d[0]->branch_length($bl + ($d[0]->branch_length || 0));
-	   $a1->add_Descendent($d[0]);
-	   $a1->remove_Descendent($self);
-       }
-   }
    $c;
 }
 
@@ -299,10 +356,15 @@ sub remove_Descendent{
 
 sub remove_all_Descendents{
    my ($self) = @_;
-   # this won't cleanup the nodes themselves if you also have
+   # This won't cleanup the nodes themselves if you also have
    # a copy/pointer of them (I think)...
+   
+   # That's true.  But that's not a bug; if we retain a reference to them it's
+   # very possible we want to keep them.  The only way to truly destroy them is
+   # to call DESTROY on the instance.
+   
    while( my ($node,$val) = each %{ $self->{'_desc'} } ) {
-       $val->ancestor(undef);
+       delete $self->{'_desc'}->{$node}
    }
    $self->{'_desc'} = {};
    1;
@@ -356,7 +418,7 @@ sub ancestor {
                 $self->{_setting_ancestor} = 0;
             }
         }
-        weaken($self->{'_ancestor'} = $new_ancestor);
+        $self->{'_ancestor'} = $new_ancestor;
     }
     
     return $self->{'_ancestor'};
@@ -530,14 +592,6 @@ sub is_Leaf {
     return $isleaf;
 }
 
-=head2 to_string
-
- Title   : to_string
- Usage   : my $str = $node->to_string()
- Function: For debugging, provide a node as a string
- Returns : string
- Args    : none
-
 =head2 height
 
  Title   : height
@@ -719,14 +773,17 @@ sub node_cleanup {
     
     #*** below is wrong, cleanup doesn't actually occur. Will replace with:
     # $self->remove_all_Descendents; once further fixes in place..
-    if( defined $self->{'_desc'} &&
-        ref($self->{'_desc'}) =~ /HASH/i ) {
-        while( my ($nodeid,$node) = each %{ $self->{'_desc'} } ) {
-            $node->ancestor(undef); # insure no circular references
-            $node = undef;
-        }
-    }
-    $self->{'_desc'} = {};
+    #if( defined $self->{'_desc'} &&
+    #    ref($self->{'_desc'}) =~ /HASH/i ) {
+    #    while( my ($nodeid,$node) = each %{ $self->{'_desc'} } ) {
+    #        $node->ancestor(undef); # insure no circular references
+    #        $node = undef;
+    #    }
+    #}
+    $self->remove_all_Descendents;
+    
+    #$self->{'_desc'} = {};
+    1;
 }
 
 =head2 reverse_edge
